@@ -25,13 +25,12 @@ def ask_to_proceed() -> None:
     :doc-author: Julian M. Kleber
     """
 
-    answer = input(
-        f"Are you sure that you want to proceed {fearful_face}? (y/n)")
+    answer = input(f"Wouldn't it be better to stop {fearful_face}? (y/n)\n")
     answer = answer.lower()
 
-    if answer == "y":
+    if answer == "n":
         echo(f"Okay, I guess you got this... {pensive_face}")
-    elif answer == "n":
+    elif answer == "y":
         echo(f"Good decision, darling {magic_wand} {kissing_cat} ")
         sys.exit()
     else:
