@@ -49,7 +49,8 @@ def verify_branch() -> None:
 
     else:
         echo(
-            f"It seems like the way is free for you to go ahead {magic_wand} {kissing_cat}"
+            "It seems like you are on a good branch.\n"
+            f"The way is free for you to go ahead {magic_wand} {kissing_cat}"
         )
 
 
