@@ -121,8 +121,8 @@ def say_message() -> None:
     message = (
         f"{anatomical_heart} Lia is an open-source CI/CD tool\n"
         f"that eliminates the Fel {mechanical_arm}\n"
-        f" Copyright © 2023 Soul Twin Studios {call_me_hand},\n"
-        f"a subsidiary of SailBlack Inc. {sailing_ship}"
+        f"Copyright © 2023 Soul Twin Studios {call_me_hand}\n"
+        f"A subsidiary of SailBlack Inc. {sailing_ship}"
     )
     echo(message=message)
 
@@ -137,11 +137,11 @@ def say_end_message() -> None:
     sailing_ship = emojize(":sailboat:")
 
     message = (
-        f"Thank you for using Lia."
+        f"Thank you for using Lia.\n"
         f"{anatomical_heart} Lia is an open-source CI/CD tool\n"
         f"that eliminates the Fel {mechanical_arm}\n"
-        f"Copyright © 2023 Soul Twin Studios {call_me_hand},\n"
-        f"a subsidiary of SailBlack Inc. {sailing_ship}\n"
+        f"Copyright © 2023 Soul Twin Studios {call_me_hand}\n"
+        f"A subsidiary of SailBlack Inc. {sailing_ship}\n"
         f"For more nice things follow us on www.codeberg.org/sail.black"
     )
     echo(message=message)
